@@ -112,9 +112,10 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 		middlewares.NewRDSClusterInstanceExpander(d.resourceFactory),
 		middlewares.NewAwsApiGatewayDeploymentExpander(d.resourceFactory),
 		middlewares.NewAwsApiGatewayResourceExpander(d.resourceFactory),
-		middlewares.NewAwsApiGatewayRestApiExpander(d.resourceFactory),
+		middlewares.NewAwsApiGatewayApiExpander(d.resourceFactory),
 		middlewares.NewAwsApiGatewayRestApiPolicyExpander(d.resourceFactory),
 		middlewares.NewAwsConsoleApiGatewayGatewayResponse(),
+		middlewares.NewAwsApiGatewayDomainNamesReconciler(),
 
 		middlewares.NewGoogleIAMBindingTransformer(d.resourceFactory),
 		middlewares.NewGoogleIAMPolicyTransformer(d.resourceFactory),
@@ -128,6 +129,7 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 			middlewares.NewAwsDefaults(),
 			middlewares.NewGoogleLegacyBucketIAMMember(),
 			middlewares.NewGoogleDefaultIAMMember(),
+			middlewares.NewAwsDefaultApiGatewayAccount(),
 		)
 	}
 
