@@ -13,11 +13,11 @@ import (
 )
 
 type container struct {
-	Credentials struct {
-		TerraformCloud struct {
-			Token string
-		} `json:"app.terraform.io"`
-	}
+	Credentials map[string]containerToken
+}
+
+type containerToken struct {
+	Token string
 }
 
 type tfCloudConfigReader struct {
@@ -28,7 +28,7 @@ func NewTFCloudConfigReader(reader io.ReadCloser) *tfCloudConfigReader {
 	return &tfCloudConfigReader{reader}
 }
 
-func (r *tfCloudConfigReader) GetToken() (string, error) {
+func (r *tfCloudConfigReader) GetToken(host string) (string, error) {
 	b, err := ioutil.ReadAll(r.reader)
 	if err != nil {
 		return "", errors.New("unable to read file")
@@ -38,10 +38,10 @@ func (r *tfCloudConfigReader) GetToken() (string, error) {
 	if err := json.Unmarshal(b, &container); err != nil {
 		return "", err
 	}
-	if container.Credentials.TerraformCloud.Token == "" {
+	if container.Credentials[host].Token == "" {
 		return "", errors.New("driftctl could not read your Terraform configuration file, please check that this is a valid Terraform credentials file")
 	}
-	return container.Credentials.TerraformCloud.Token, nil
+	return container.Credentials[host].Token, nil
 }
 
 func getTerraformConfigFile() (string, error) {
