@@ -4,9 +4,9 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/remote/cache"
-	awstest "github.com/cloudskiff/driftctl/test/aws"
 	"github.com/pkg/errors"
+	"github.com/snyk/driftctl/pkg/remote/cache"
+	awstest "github.com/snyk/driftctl/test/aws"
 	"github.com/stretchr/testify/mock"
 
 	"github.com/aws/aws-sdk-go/service/ec2"
@@ -1277,3 +1277,81 @@ func Test_ec2Repository_ListAllNetworkACLs(t *testing.T) {
 		})
 	}
 }
+
+func Test_ec2Repository_DescribeLaunchTemplates(t *testing.T) {
+
+	testErr := errors.New("test")
+
+	tests := []struct {
+		name    string
+		mocks   func(client *awstest.MockFakeEC2)
+		want    []*ec2.LaunchTemplate
+		wantErr error
+	}{
+		{
+			name: "List with 1 pages",
+			mocks: func(client *awstest.MockFakeEC2) {
+				client.On("DescribeLaunchTemplates",
+					&ec2.DescribeLaunchTemplatesInput{},
+				).Return(&ec2.DescribeLaunchTemplatesOutput{
+					LaunchTemplates: []*ec2.LaunchTemplate{
+						{
+							LaunchTemplateId: aws.String("id1"),
+						},
+						{
+							LaunchTemplateId: aws.String("id2"),
+						},
+					},
+				}, nil).Once()
+			},
+			want: []*ec2.LaunchTemplate{
+				{
+					LaunchTemplateId: aws.String("id1"),
+				},
+				{
+					LaunchTemplateId: aws.String("id2"),
+				},
+			},
+		},
+		{
+			name: "List return error",
+			mocks: func(client *awstest.MockFakeEC2) {
+				client.On("DescribeLaunchTemplates",
+					&ec2.DescribeLaunchTemplatesInput{},
+				).Return(nil, testErr)
+			},
+			wantErr: testErr,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			store := cache.New(1)
+			client := &awstest.MockFakeEC2{}
+			tt.mocks(client)
+			r := &ec2Repository{
+				client: client,
+				cache:  store,
+			}
+			got, err := r.DescribeLaunchTemplates()
+			assert.Equal(t, tt.wantErr, err)
+
+			if err == nil {
+				// Check that results were cached
+				cachedData, err := r.DescribeLaunchTemplates()
+				assert.NoError(t, err)
+				assert.Equal(t, got, cachedData)
+				assert.IsType(t, []*ec2.LaunchTemplate{}, store.Get("DescribeLaunchTemplates"))
+			}
+
+			changelog, err := diff.Diff(got, tt.want)
+			assert.Nil(t, err)
+			if len(changelog) > 0 {
+				for _, change := range changelog {
+					t.Errorf("%s: %s -> %s", strings.Join(change.Path, "."), change.From, change.To)
+				}
+				t.Fail()
+			}
+			client.AssertExpectations(t)
+		})
+	}
+}
