@@ -3,22 +3,22 @@ package remote
 import (
 	"testing"
 
-	"github.com/cloudskiff/driftctl/mocks"
-	"github.com/cloudskiff/driftctl/pkg/filter"
-	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
-	"github.com/cloudskiff/driftctl/pkg/remote/cache"
-	"github.com/cloudskiff/driftctl/pkg/remote/common"
-	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
-	"github.com/cloudskiff/driftctl/pkg/remote/google"
-	"github.com/cloudskiff/driftctl/pkg/remote/google/repository"
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	googleresource "github.com/cloudskiff/driftctl/pkg/resource/google"
-	"github.com/cloudskiff/driftctl/pkg/terraform"
-	"github.com/cloudskiff/driftctl/test"
-	"github.com/cloudskiff/driftctl/test/goldenfile"
-	testgoogle "github.com/cloudskiff/driftctl/test/google"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
-	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
+	"github.com/snyk/driftctl/mocks"
+	"github.com/snyk/driftctl/pkg/filter"
+	"github.com/snyk/driftctl/pkg/remote/alerts"
+	"github.com/snyk/driftctl/pkg/remote/cache"
+	"github.com/snyk/driftctl/pkg/remote/common"
+	remoteerr "github.com/snyk/driftctl/pkg/remote/error"
+	"github.com/snyk/driftctl/pkg/remote/google"
+	"github.com/snyk/driftctl/pkg/remote/google/repository"
+	"github.com/snyk/driftctl/pkg/resource"
+	googleresource "github.com/snyk/driftctl/pkg/resource/google"
+	"github.com/snyk/driftctl/pkg/terraform"
+	"github.com/snyk/driftctl/test"
+	"github.com/snyk/driftctl/test/goldenfile"
+	testgoogle "github.com/snyk/driftctl/test/google"
+	testresource "github.com/snyk/driftctl/test/resource"
+	terraform2 "github.com/snyk/driftctl/test/terraform"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 	assetpb "google.golang.org/genproto/googleapis/cloud/asset/v1"
@@ -1323,3 +1323,113 @@ func TestGoogleComputeHealthCheck(t *testing.T) {
 		})
 	}
 }
+
+func TestGoogleComputeNodeGroup(t *testing.T) {
+
+	cases := []struct {
+		test             string
+		assertExpected   func(t *testing.T, got []*resource.Resource)
+		response         []*assetpb.Asset
+		responseErr      error
+		setupAlerterMock func(alerter *mocks.AlerterInterface)
+		wantErr          error
+	}{
+		{
+			test:     "no compute node group",
+			response: []*assetpb.Asset{},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 0)
+			},
+		},
+		{
+			test: "multiples compute node group",
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 2)
+				assert.Equal(t, "projects/cloudskiff-dev-martin/zones/us-central1-f/nodeGroups/soletenant-group", got[0].ResourceId())
+				assert.Equal(t, "google_compute_node_group", got[0].ResourceType())
+
+				assert.Equal(t, "projects/cloudskiff-dev-martin/zones/us-central1-f/nodeGroups/simple-group", got[1].ResourceId())
+				assert.Equal(t, "google_compute_node_group", got[1].ResourceType())
+			},
+			response: []*assetpb.Asset{
+				{
+					AssetType: "compute.googleapis.com/NodeGroup",
+					Name:      "//compute.googleapis.com/projects/cloudskiff-dev-martin/zones/us-central1-f/nodeGroups/soletenant-group",
+				},
+				{
+					AssetType: "compute.googleapis.com/NodeGroup",
+					Name:      "//compute.googleapis.com/projects/cloudskiff-dev-martin/zones/us-central1-f/nodeGroups/simple-group",
+				},
+			},
+		},
+		{
+			test: "cannot list compute node group",
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 0)
+			},
+			responseErr: status.Error(codes.PermissionDenied, "The caller does not have permission"),
+			setupAlerterMock: func(alerter *mocks.AlerterInterface) {
+				alerter.On(
+					"SendAlert",
+					"google_compute_node_group",
+					alerts.NewRemoteAccessDeniedAlert(
+						common.RemoteGoogleTerraform,
+						remoteerr.NewResourceListingError(
+							status.Error(codes.PermissionDenied, "The caller does not have permission"),
+							"google_compute_node_group",
+						),
+						alerts.EnumerationPhase,
+					),
+				).Once()
+			},
+		},
+	}
+
+	providerVersion := "3.78.0"
+	schemaRepository := testresource.InitFakeSchemaRepository(terraform.GOOGLE, providerVersion)
+	googleresource.InitResourcesMetadata(schemaRepository)
+	factory := terraform.NewTerraformResourceFactory(schemaRepository)
+
+	for _, c := range cases {
+		t.Run(c.test, func(tt *testing.T) {
+			scanOptions := ScannerOptions{}
+			providerLibrary := terraform.NewProviderLibrary()
+			remoteLibrary := common.NewRemoteLibrary()
+
+			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
+			if c.setupAlerterMock != nil {
+				c.setupAlerterMock(alerter)
+			}
+
+			assetClient, err := testgoogle.NewFakeAssertServerWithList(c.response, c.responseErr)
+			if err != nil {
+				tt.Fatal(err)
+			}
+
+			realProvider, err := terraform2.InitTestGoogleProvider(providerLibrary, providerVersion)
+			if err != nil {
+				tt.Fatal(err)
+			}
+
+			repo := repository.NewAssetRepository(assetClient, realProvider.GetConfig(), cache.New(0))
+
+			remoteLibrary.AddEnumerator(google.NewGoogleComputeNodeGroupEnumerator(repo, factory))
+
+			testFilter := &filter.MockFilter{}
+			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
+
+			s := NewScanner(remoteLibrary, alerter, scanOptions, testFilter)
+			got, err := s.Resources()
+			assert.Equal(tt, err, c.wantErr)
+			if err != nil {
+				return
+			}
+			alerter.AssertExpectations(tt)
+			testFilter.AssertExpectations(tt)
+			if c.assertExpected != nil {
+				c.assertExpected(t, got)
+			}
+		})
+	}
+}
