@@ -6,23 +6,23 @@ import (
 
 	asset "cloud.google.com/go/asset/apiv1"
 	"cloud.google.com/go/storage"
-	"github.com/cloudskiff/driftctl/mocks"
-	"github.com/cloudskiff/driftctl/pkg/filter"
-	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
-	"github.com/cloudskiff/driftctl/pkg/remote/cache"
-	"github.com/cloudskiff/driftctl/pkg/remote/common"
-	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
-	"github.com/cloudskiff/driftctl/pkg/remote/google"
-	"github.com/cloudskiff/driftctl/pkg/remote/google/repository"
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	googleresource "github.com/cloudskiff/driftctl/pkg/resource/google"
-	"github.com/cloudskiff/driftctl/pkg/terraform"
-	"github.com/cloudskiff/driftctl/test"
-	"github.com/cloudskiff/driftctl/test/goldenfile"
-	testgoogle "github.com/cloudskiff/driftctl/test/google"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
-	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
 	"github.com/pkg/errors"
+	"github.com/snyk/driftctl/mocks"
+	"github.com/snyk/driftctl/pkg/filter"
+	"github.com/snyk/driftctl/pkg/remote/alerts"
+	"github.com/snyk/driftctl/pkg/remote/cache"
+	"github.com/snyk/driftctl/pkg/remote/common"
+	remoteerr "github.com/snyk/driftctl/pkg/remote/error"
+	"github.com/snyk/driftctl/pkg/remote/google"
+	"github.com/snyk/driftctl/pkg/remote/google/repository"
+	"github.com/snyk/driftctl/pkg/resource"
+	googleresource "github.com/snyk/driftctl/pkg/resource/google"
+	"github.com/snyk/driftctl/pkg/terraform"
+	"github.com/snyk/driftctl/test"
+	"github.com/snyk/driftctl/test/goldenfile"
+	testgoogle "github.com/snyk/driftctl/test/google"
+	testresource "github.com/snyk/driftctl/test/resource"
+	terraform2 "github.com/snyk/driftctl/test/terraform"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 	assetpb "google.golang.org/genproto/googleapis/cloud/asset/v1"
