@@ -4,19 +4,19 @@ import (
 	"errors"
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
-	"github.com/cloudskiff/driftctl/pkg/remote/common"
-	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
-	resourcegithub "github.com/cloudskiff/driftctl/pkg/resource/github"
+	"github.com/snyk/driftctl/pkg/remote/alerts"
+	"github.com/snyk/driftctl/pkg/remote/common"
+	remoteerr "github.com/snyk/driftctl/pkg/remote/error"
+	resourcegithub "github.com/snyk/driftctl/pkg/resource/github"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 
 	"github.com/stretchr/testify/assert"
 
 	"github.com/aws/aws-sdk-go/aws/awserr"
-	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
+	resourceaws "github.com/snyk/driftctl/pkg/resource/aws"
 
-	"github.com/cloudskiff/driftctl/pkg/alerter"
+	"github.com/snyk/driftctl/pkg/alerter"
 )
 
 func TestHandleAwsEnumerationErrors(t *testing.T) {
