@@ -4,8 +4,8 @@ import (
 	"testing"
 	"time"
 
-	"github.com/cloudskiff/driftctl/test"
-	"github.com/cloudskiff/driftctl/test/acceptance"
+	"github.com/snyk/driftctl/test"
+	"github.com/snyk/driftctl/test/acceptance"
 )
 
 func TestAcc_AwsInternetGateway(t *testing.T) {
