@@ -3,9 +3,9 @@ package aws_test
 import (
 	"testing"
 
-	"github.com/cloudskiff/driftctl/test"
+	"github.com/snyk/driftctl/test"
 
-	"github.com/cloudskiff/driftctl/test/acceptance"
+	"github.com/snyk/driftctl/test/acceptance"
 )
 
 func TestAcc_AwsVPC(t *testing.T) {
