@@ -141,12 +141,21 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_appautoscaling_scheduled_action": {},
 	"aws_apigatewayv2_api": {children: []ResourceType{
 		"aws_apigatewayv2_route",
+		"aws_apigatewayv2_integration",
 	}},
-	"aws_apigatewayv2_route":      {},
-	"aws_apigatewayv2_vpc_link":   {},
-	"aws_apigatewayv2_authorizer": {},
-	"aws_launch_template":         {},
-	"aws_launch_configuration":    {},
+	"aws_apigatewayv2_model":                {},
+	"aws_apigatewayv2_stage":                {},
+	"aws_apigatewayv2_route_response":       {},
+	"aws_apigatewayv2_deployment":           {},
+	"aws_apigatewayv2_domain_name":          {},
+	"aws_apigatewayv2_api_mapping":          {},
+	"aws_apigatewayv2_route":                {},
+	"aws_apigatewayv2_vpc_link":             {},
+	"aws_apigatewayv2_authorizer":           {},
+	"aws_apigatewayv2_integration":          {},
+	"aws_apigatewayv2_integration_response": {},
+	"aws_launch_template":                   {},
+	"aws_launch_configuration":              {},
 
 	"github_branch_protection": {},
 	"github_membership":        {},
