@@ -5,12 +5,6 @@ type Supplier interface {
 	Resources() ([]*Resource, error)
 }
 
-type RemoteSupplier interface {
-	Supplier
-	EnumerateResources() ([]*Resource, error)
-	ReadResources([]*Resource) ([]*Resource, error)
-}
-
 type StoppableSupplier interface {
 	Supplier
 	Stop()
